baseline_table = [
  {
    "index": 1,
    "submission_id": "neversleep-noromaid-13b-v0-3_v16",
    "developer_uid": "decem_y",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 177,
    "thumbs_down": 47,
    "total_feedback_count": 224
  },
  {
    "index": 2,
    "submission_id": "andrijdavid-smaugroleplay_v1",
    "developer_uid": "andrij",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 38,
    "thumbs_down": 96,
    "total_feedback_count": 134
  },
  {
    "index": 3,
    "submission_id": "ssaryssane-awesome-bagel-34b_v15",
    "developer_uid": "ssaryssane",
    "status": "deployed",
    "double_thumbs_up": 17,
    "thumbs_up": 24,
    "thumbs_down": 33,
    "total_feedback_count": 74
  },
  {
    "index": 4,
    "submission_id": "fredithefish-baboon_v25",
    "developer_uid": "fredi",
    "status": "deployed",
    "double_thumbs_up": 27,
    "thumbs_up": 64,
    "thumbs_down": 57,
    "total_feedback_count": 148
  },
  {
    "index": 5,
    "submission_id": "fredithefish-baboon_v26",
    "developer_uid": "fredi",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 199,
    "thumbs_down": 58,
    "total_feedback_count": 257
  },
  {
    "index": 6,
    "submission_id": "neversleep-noromaid-13b-v0-3_v18",
    "developer_uid": "Chenyue",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 168,
    "thumbs_down": 61,
    "total_feedback_count": 229
  },
  {
    "index": 7,
    "submission_id": "anhnv125-pawn_v3",
    "developer_uid": "vietanh",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 208,
    "thumbs_down": 63,
    "total_feedback_count": 271
  },
  {
    "index": 8,
    "submission_id": "wendyhoang-med-rp-model_v2",
    "developer_uid": "wendyhoang",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 209,
    "thumbs_down": 63,
    "total_feedback_count": 272
  },
  {
    "index": 9,
    "submission_id": "mistralai-mistral-7b-instruct_v2",
    "developer_uid": "pembroke",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 157,
    "thumbs_down": 112,
    "total_feedback_count": 269
  },
  {
    "index": 10,
    "submission_id": "wendyhoang-med-rp-model_v3",
    "developer_uid": "wendyhoang",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 233,
    "thumbs_down": 53,
    "total_feedback_count": 286
  },
  {
    "index": 11,
    "submission_id": "katydeng-katy_v4",
    "developer_uid": "kathy196",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 189,
    "thumbs_down": 65,
    "total_feedback_count": 254
  },
  {
    "index": 12,
    "submission_id": "vectorboi-bluemodel_v1",
    "developer_uid": ".vectorized",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 127,
    "thumbs_down": 122,
    "total_feedback_count": 249
  },
  {
    "index": 13,
    "submission_id": "roleplay4fun-sleepless-v1-3_v1",
    "developer_uid": "gau",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 176,
    "thumbs_down": 59,
    "total_feedback_count": 235
  },
  {
    "index": 14,
    "submission_id": "roleplay4fun-sleepless-girl-v_v2",
    "developer_uid": "gau",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 194,
    "thumbs_down": 45,
    "total_feedback_count": 239
  },
  {
    "index": 15,
    "submission_id": "zac-nguyen-llama-ultra_v1",
    "developer_uid": "cute_dragon_99320",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 185,
    "thumbs_down": 55,
    "total_feedback_count": 240
  },
  {
    "index": 16,
    "submission_id": "zac-nguyen-llama-ultra2_v1",
    "developer_uid": "cute_dragon_99320",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 195,
    "thumbs_down": 45,
    "total_feedback_count": 240
  },
  {
    "index": 17,
    "submission_id": "sao10k-fimbulvetr-10-7b-v1_v3",
    "developer_uid": "sao10k",
    "status": "deployed",
    "double_thumbs_up": 23,
    "thumbs_up": 155,
    "thumbs_down": 67,
    "total_feedback_count": 245
  },
  {
    "index": 18,
    "submission_id": "sao10k-fimbulvetr-11b-v2-test_v1",
    "developer_uid": "sao10k",
    "status": "deployed",
    "double_thumbs_up": 8,
    "thumbs_up": 151,
    "thumbs_down": 54,
    "total_feedback_count": 213
  },
  {
    "index": 19,
    "submission_id": "gotchu-season-8-13bmergev1_v1",
    "developer_uid": "a.a6523",
    "status": "deployed",
    "double_thumbs_up": 0,
    "thumbs_up": 117,
    "thumbs_down": 39,
    "total_feedback_count": 156
  },
  {
    "index": 20,
    "submission_id": "anhnv125-pawn-v3_v1",
    "developer_uid": "vietanh",
    "status": "deployed",
    "double_thumbs_up": 9,
    "thumbs_up": 163,
    "thumbs_down": 42,
    "total_feedback_count": 214
  },
  {
    "index": 21,
    "submission_id": "khanhnto-kyt-goat-13b_v3",
    "developer_uid": "otuey",
    "status": "deployed",
    "double_thumbs_up": 8,
    "thumbs_up": 157,
    "thumbs_down": 51,
    "total_feedback_count": 216
  },
  {
    "index": 22,
    "submission_id": "psiilu-my-mdl1_v17",
    "developer_uid": "kaggleGM",
    "status": "deployed",
    "double_thumbs_up": 35,
    "thumbs_up": 135,
    "thumbs_down": 34,
    "total_feedback_count": 204
  },
  {
    "index": 23,
    "submission_id": "decem-staphylus-llama-v1-9_v7",
    "developer_uid": "decem_y",
    "status": "deployed",
    "double_thumbs_up": 35,
    "thumbs_up": 142,
    "thumbs_down": 25,
    "total_feedback_count": 202
  },
  {
    "index": 24,
    "submission_id": "ssaryssane-ssary-solar-10-7b_v1",
    "developer_uid": "ssaryssane",
    "status": "deployed",
    "double_thumbs_up": 28,
    "thumbs_up": 108,
    "thumbs_down": 57,
    "total_feedback_count": 193
  },
  {
    "index": 25,
    "submission_id": "hflserdaniel-chai-s6-13b-slp3_v9",
    "developer_uid": "Chenyue",
    "status": "deployed",
    "double_thumbs_up": 33,
    "thumbs_up": 129,
    "thumbs_down": 47,
    "total_feedback_count": 209
  },
  {
    "index": 26,
    "submission_id": "khanhnto-kyt-dragon-13b_v1",
    "developer_uid": "otuey",
    "status": "deployed",
    "double_thumbs_up": 31,
    "thumbs_up": 116,
    "thumbs_down": 58,
    "total_feedback_count": 205
  },
  {
    "index": 27,
    "submission_id": "gotchu-s8-knarf-2_v2",
    "developer_uid": "a.a6523",
    "status": "deployed",
    "double_thumbs_up": 19,
    "thumbs_up": 75,
    "thumbs_down": 32,
    "total_feedback_count": 126
  },
  {
    "index": 28,
    "submission_id": "katydeng-katy-new_v1",
    "developer_uid": "kathy196",
    "status": "deployed",
    "double_thumbs_up": 21,
    "thumbs_up": 55,
    "thumbs_down": 17,
    "total_feedback_count": 93
  },
  {
    "index": 29,
    "submission_id": "alkahestry-pointer-mist_v40",
    "developer_uid": "alkacchi",
    "status": "deployed",
    "double_thumbs_up": 139,
    "thumbs_up": 320,
    "thumbs_down": 130,
    "total_feedback_count": 589
  },
  {
    "index": 30,
    "submission_id": "alkahestry-pointer-mist_v41",
    "developer_uid": "alkacchi",
    "status": "deployed",
    "double_thumbs_up": 27,
    "thumbs_up": 72,
    "thumbs_down": 37,
    "total_feedback_count": 136
  },
  {
    "index": 31,
    "submission_id": "blend_milat_2024-02-09",
    "developer_uid": "khoangothe",
    "status": "deployed",
    "double_thumbs_up": 18,
    "thumbs_up": 56,
    "thumbs_down": 13,
    "total_feedback_count": 87
  },
  {
    "index": 32,
    "submission_id": "blend_jofin_2024-02-09",
    "developer_uid": "khoangothe",
    "status": "deployed",
    "double_thumbs_up": 21,
    "thumbs_up": 51,
    "thumbs_down": 17,
    "total_feedback_count": 89
  },
  {
    "index": 33,
    "submission_id": "blend_lopok_2024-02-09",
    "developer_uid": "kaggleGM",
    "status": "deployed",
    "double_thumbs_up": 26,
    "thumbs_up": 38,
    "thumbs_down": 17,
    "total_feedback_count": 81
  },
  {
    "index": 34,
    "submission_id": "blend_mepil_2024-02-09",
    "developer_uid": "liquaciousmalice",
    "status": "deployed",
    "double_thumbs_up": 15,
    "thumbs_up": 41,
    "thumbs_down": 16,
    "total_feedback_count": 72
  },
  {
    "index": 35,
    "submission_id": "blend_butib_2024-02-09",
    "developer_uid": "liquaciousmalice",
    "status": "deployed",
    "double_thumbs_up": 15,
    "thumbs_up": 45,
    "thumbs_down": 15,
    "total_feedback_count": 75
  }
]

baseline_dict = {
    data['submission_id']: data for data in baseline_table
}